pub struct DisplayList { /* private fields */ }Expand description
An ordered list of drawing operations for a single page.
Implementations
Sourceimpl DisplayList
impl DisplayList
Sourcepub fn page_group_color_space(&self) -> GroupColorSpace
pub fn page_group_color_space(&self) -> GroupColorSpace
Returns the page-level transparency group color space.
Sourcepub fn set_page_group_color_space(&mut self, cs: GroupColorSpace)
pub fn set_page_group_color_space(&mut self, cs: GroupColorSpace)
Set the page-level transparency group color space (called by the PDF
reader when the page dictionary declares a /Group /CS).
Sourcepub fn push(&mut self, element: DisplayElement)
pub fn push(&mut self, element: DisplayElement)
Append a drawing operation.
Sourcepub fn elements(&self) -> &[DisplayElement]
pub fn elements(&self) -> &[DisplayElement]
Access recorded elements.
Sourcepub fn elements_from(&self, start: usize) -> &[DisplayElement]
pub fn elements_from(&self, start: usize) -> &[DisplayElement]
Returns a slice of elements starting from the given index.
Sourcepub fn split_off(&mut self, start: usize) -> DisplayList
pub fn split_off(&mut self, start: usize) -> DisplayList
Drain elements from start.. into a new DisplayList, truncating self.
Sourcepub fn into_elements(self) -> Vec<DisplayElement>
pub fn into_elements(self) -> Vec<DisplayElement>
Consume the display list and return the elements.