pub struct PatternFillParams {Show 14 fields
pub path: PsPath,
pub fill_rule: FillRule,
pub tile: DisplayList,
pub pattern_matrix: Matrix,
pub bbox: [f64; 4],
pub xstep: f64,
pub ystep: f64,
pub paint_type: i32,
pub underlying_color: Option<DeviceColor>,
pub pattern_id: u32,
pub device_space_tile: bool,
pub flip_tile_y: bool,
pub stroke_params: Option<StrokeParams>,
pub overprint_mode: i32,
}Expand description
Parameters for a tiled pattern fill.
Fields
path: PsPathThe path to fill with the pattern.
fill_rule: FillRuleFill rule for the path.
tile: DisplayListPre-rendered display list for a single tile.
pattern_matrix: MatrixPattern matrix (pattern space → device space).
bbox: [f64; 4]Bounding box of one tile in pattern space.
xstep: f64Horizontal step between tile origins.
ystep: f64Vertical step between tile origins.
paint_type: i32Paint type: 1 = colored, 2 = uncolored.
underlying_color: Option<DeviceColor>For uncolored patterns, the fill color.
pattern_id: u32Unique pattern ID from pattern_store (for dedup in PDF output).
device_space_tile: boolWhen true, tile display list elements have CTMs in device space (the pattern matrix is already baked into element transforms). When false, elements are in pattern space and the renderer applies the pattern_matrix during rendering.
flip_tile_y: boolWhen true, the tile content was designed for a Y-flipped coordinate system (pattern matrix had negative d). The pre-rendered tile must be vertically flipped before stamping.
stroke_params: Option<StrokeParams>For pattern strokes: stroke parameters to expand the centerline path
into a fill outline for masking. When Some, path is a user-space
stroke centerline rather than a fill path.
overprint_mode: i32PDF overprint mode (0 or 1). When 1, CMYK(0,0,0,0) pixels in tile images are transparent (no ink = don’t paint).